@@ -9,7 +9,14 @@ becas-python - becas API client for Python
 **becas** is a biomedical concept annotator available through an HTTP API.
 
 This package allows usage of the becas API from a command-line tool or
-programatically from Python modules.
+programmatically from Python modules.
+
+Install it with::
+
+    $ pip install becas
+
+And learn to use it by reading the `documentation`_.
+
 
 :copyright: (c) 2013, Tiago Nunes, Universidade de Aveiro
 :license: Creative Commons Attribution-Noncommercial
@@ -27,7 +34,7 @@ Resources
 '''
 
 __title__ = 'becas'
-__version__ = '1.0.2'
+__version__ = '1.0.3'
 __author__ = 'Tiago Nunes'
 __license__ = 'CC-BY-NC'
 __copyright__ = 'Copyright 2013, Tiago Nunes, Universidade de Aveiro'
